# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: data_entry.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'data_entry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x64\x61ta_entry.proto\x12\rliberal.alpha\"\xb2\x02\n\tDataEntry\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\x04\x12\x11\n\trecord_id\x18\x02 \x01(\r\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x04 \x03(\x01\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\x12\x18\n\x10runner_timestamp\x18\x06 \x01(\x03\x12\x18\n\x10server_timestamp\x18\x07 \x01(\x03\x12\x1c\n\x0f\x61s_of_timestamp\x18\x08 \x01(\x03H\x00\x88\x01\x01\x12\x17\n\nrequest_id\x18\t \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08\x62\x61tch_id\x18\n \x01(\rH\x02\x88\x01\x01\x12\x19\n\x11\x65ncrypted_payload\x18\x0b \x01(\x0c\x42\x12\n\x10_as_of_timestampB\r\n\x0b_request_idB\x0b\n\t_batch_id\"K\n\x11ProducerHandshake\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x11\n\trunner_id\x18\x02 \x01(\t\x12\x12\n\nrecord_ids\x18\x03 \x03(\r\"O\n\x19ProducerHandshakeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\xed\x01\n\x0fProducerMessage\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.liberal.alpha.ProducerMessage.MessageType\x12\x30\n\x0csingle_entry\x18\x02 \x01(\x0b\x32\x18.liberal.alpha.DataEntryH\x00\x12\x30\n\x05\x62\x61tch\x18\x03 \x01(\x0b\x32\x1f.liberal.alpha.BatchDataRequestH\x00\"1\n\x0bMessageType\x12\x08\n\x04\x44\x41TA\x10\x00\x12\t\n\x05\x42\x41TCH\x10\x01\x12\r\n\tHEARTBEAT\x10\x02\x42\t\n\x07payload\"=\n\x10\x42\x61tchDataRequest\x12)\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x18.liberal.alpha.DataEntry\"\xdd\x01\n\x10ProducerResponse\x12\x36\n\x06status\x18\x01 \x01(\x0e\x32&.liberal.alpha.ProducerResponse.Status\x12\x10\n\x08\x65ntry_id\x18\x02 \x01(\x04\x12\x12\n\nrequest_id\x18\x03 \x01(\t\x12\x15\n\rerror_message\x18\x04 \x01(\t\x12\x18\n\x10server_timestamp\x18\x05 \x01(\x03\":\n\x06Status\x12\x07\n\x03\x41\x43K\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x10\n\x0c\x42\x41\x43KPRESSURE\x10\x02\x12\n\n\x06RESUME\x10\x03\"\xb1\x01\n\x0f\x43onsumerMessage\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.liberal.alpha.ConsumerMessage.MessageType\x12\'\n\x05\x65ntry\x18\x02 \x01(\x0b\x32\x18.liberal.alpha.DataEntry\x12\x13\n\x0bserver_time\x18\x03 \x01(\x03\"&\n\x0bMessageType\x12\x08\n\x04\x44\x41TA\x10\x00\x12\r\n\tHEARTBEAT\x10\x01\x42\x0fZ\rbackend/protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_entry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\rbackend/proto'
  _globals['_DATAENTRY']._serialized_start=36
  _globals['_DATAENTRY']._serialized_end=342
  _globals['_PRODUCERHANDSHAKE']._serialized_start=344
  _globals['_PRODUCERHANDSHAKE']._serialized_end=419
  _globals['_PRODUCERHANDSHAKERESPONSE']._serialized_start=421
  _globals['_PRODUCERHANDSHAKERESPONSE']._serialized_end=500
  _globals['_PRODUCERMESSAGE']._serialized_start=503
  _globals['_PRODUCERMESSAGE']._serialized_end=740
  _globals['_PRODUCERMESSAGE_MESSAGETYPE']._serialized_start=680
  _globals['_PRODUCERMESSAGE_MESSAGETYPE']._serialized_end=729
  _globals['_BATCHDATAREQUEST']._serialized_start=742
  _globals['_BATCHDATAREQUEST']._serialized_end=803
  _globals['_PRODUCERRESPONSE']._serialized_start=806
  _globals['_PRODUCERRESPONSE']._serialized_end=1027
  _globals['_PRODUCERRESPONSE_STATUS']._serialized_start=969
  _globals['_PRODUCERRESPONSE_STATUS']._serialized_end=1027
  _globals['_CONSUMERMESSAGE']._serialized_start=1030
  _globals['_CONSUMERMESSAGE']._serialized_end=1207
  _globals['_CONSUMERMESSAGE_MESSAGETYPE']._serialized_start=1169
  _globals['_CONSUMERMESSAGE_MESSAGETYPE']._serialized_end=1207
# @@protoc_insertion_point(module_scope)
